<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2020 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Controller;

use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use JchOptimize\Core\Admin\Tasks;
use JchOptimize\Model\Cache;
use JchOptimize\Model\OrderPlugins;
use Joomla\Application\AbstractApplication;
use Joomla\CMS\Router\Route as JRoute;
use Joomla\Input\Input;

\defined('_JEXEC') or exit('Restricted Access');
class Utility extends AbstractController
{
    /**
     * Message to enqueue by application.
     *
     * @var string;
     */
    private $message;

    /**
     * Message type.
     *
     * @var string
     */
    private $messageType = 'success';

    /**
     * Url to redirect to.
     *
     * @var string
     */
    private $redirectUrl;

    /**
     * @var OrderPlugins
     */
    private $orderPluginsModel;

    /**
     * @var Cache
     *
     * @since version
     */
    private $cacheModel;

    /**
     * Constructor.
     */
    public function __construct(OrderPlugins $orderPluginsModel, Cache $cacheModel, ?Input $input = null, ?AbstractApplication $app = null)
    {
        $this->orderPluginsModel = $orderPluginsModel;
        $this->cacheModel = $cacheModel;
        parent::__construct($input, $app);
    }

    public function execute()
    {
        $this->{$this->getInput()->get('task', 'default')}();
        $this->getApplication()->enqueueMessage($this->message, $this->messageType);
        $this->getApplication()->redirect($this->redirectUrl);
    }

    private function browsercaching()
    {
        $expires = Tasks::leverageBrowserCaching();
        if (\false === $expires) {
            $this->message = \JText::_('COM_JCHOPTIMIZE_LEVERAGEBROWSERCACHE_FAILED');
            $this->messageType = 'error';
        } elseif ('FILEDOESNTEXIST' === $expires) {
            $this->message = \JText::_('COM_JCHOPTIMIZE_LEVERAGEBROWSERCACHE_FILEDOESNTEXIST');
            $this->messageType = 'warning';
        } elseif ('CODEUPDATEDSUCCESS' === $expires) {
            $this->message = \JText::_('COM_JCHOPTIMIZE_LEVERAGEBROWSERCACHE_CODEUPDATEDSUCCESS');
        } elseif ('CODEUPDATEDFAIL' === $expires) {
            $this->message = \JText::_('COM_JCHOPTIMIZE_LEVERAGEBROWSERCACHE_CODEUPDATEDFAIL');
            $this->messageType = 'notice';
        } else {
            $this->message = \JText::_('COM_JCHOPTIMIZE_LEVERAGEBROWSERCACHE_SUCCESS');
        }
        $this->redirectUrl = JRoute::_('index.php?option=com_jchoptimize', \false);
    }

    private function cleancache()
    {
        $deleted = $this->cacheModel->cleanCache();
        if (!$deleted) {
            $this->message = \JText::_('COM_JCHOPTIMIZE_CACHECLEAN_FAILED');
            $this->messageType = 'error';
        } else {
            $this->message = \JText::_('COM_JCHOPTIMIZE_CACHECLEAN_SUCCESS');
        }
        $this->redirectUrl = JRoute::_('index.php?option=com_jchoptimize', \false);
    }

    private function keycache()
    {
        Tasks::generateNewCacheKey();
        $this->message = \JText::_('COM_JCHOPTIMIZE_CACHE_KEY_GENERATED');
        $this->redirectUrl = JRoute::_('index.php?option=com_jchoptimize', \false);
    }

    private function orderplugins()
    {
        $saved = $this->orderPluginsModel->orderPlugins();
        if (\false === $saved) {
            $this->message = \JText::_('JLIB_APPLICATION_ERROR_REORDER_FAILED');
            $this->messageType = 'error';
        } else {
            $this->message = \JText::_('JLIB_APPLICATION_SUCCESS_ORDERING_SAVED');
        }
        $this->redirectUrl = JRoute::_('index.php?option=com_jchoptimize', \false);
    }

    private function restoreimages()
    {
        $mResult = Tasks::restoreBackupImages();
        if ('SOMEIMAGESDIDNTRESTORE' === $mResult) {
            $this->message = \JText::_('COM_JCHOPTIMIZE_SOMERESTOREIMAGE_FAILED');
            $this->messageType = 'warning';
        } elseif ('BACKUPPATHDOESNTEXIST' === $mResult) {
            $this->message = \JText::_('COM_JCHOPTIMIZE_BACKUPPATH_DOESNT_EXIST');
            $this->messageType = 'warning';
        } else {
            $this->message = \JText::_('COM_JCHOPTIMIZE_RESTOREIMAGE_SUCCESS');
        }
        $this->redirectUrl = JRoute::_('index.php?option=com_jchoptimize&view=OptimizeImages', \false);
    }

    private function deletebackups()
    {
        $mResult = Tasks::deleteBackupImages();
        if (\false === $mResult) {
            $this->message = \JText::_('COM_JCHOPTIMIZE_DELETEBACKUPS_FAILED');
            $this->messageType = 'error';
        } elseif ('BACKUPPATHDOESNTEXIST' === $mResult) {
            $this->message = \JText::_('COM_JCHOPTIMIZE_BACKUPPATH_DOESNT_EXIST');
            $this->messageType = 'warning';
        } else {
            $this->message = \JText::_('COM_JCHOPTIMIZE_DELETEBACKUPS_SUCCESS');
        }
        $this->redirectUrl = JRoute::_('index.php?option=com_jchoptimize&view=OptimizeImages', \false);
    }

    private function default()
    {
        $this->redirectUrl = JRoute::_('index.php?option=com_jchoptimize', \false);
    }
}
